use embed_nu::{
    nu_protocol::{engine::Command, Signature, SyntaxShape},
    CallExt,
};

#[derive(Clone)]
pub struct ErrorCommand;

impl Command for ErrorCommand {
    fn name(&self) -> &str {
        "todo"
    }

    fn signature(&self) -> embed_nu::nu_protocol::Signature {
        Signature::new("error")
            .rest("message", SyntaxShape::Any, "The error message")
            .category(embed_nu::nu_protocol::Category::Custom("Tourmaline".into()))
    }

    fn usage(&self) -> &str {
        "Throws an error"
    }

    fn run(
        &self,
        engine_state: &embed_nu::nu_protocol::engine::EngineState,
        stack: &mut embed_nu::nu_protocol::engine::Stack,
        call: &embed_nu::nu_protocol::ast::Call,
        _input: embed_nu::PipelineData,
    ) -> Result<embed_nu::PipelineData, embed_nu::nu_protocol::ShellError> {
        let args: Vec<String> = call.rest(engine_state, stack, 0)?;

        if args.is_empty() {
            Err(embed_nu::nu_protocol::ShellError::GenericError(
                String::from("Error"),
                String::from("Error"),
                Some(call.span()),
                None,
                vec![],
            ))
        } else {
            Err(embed_nu::nu_protocol::ShellError::GenericError(
                String::from("Error"),
                args.join(" "),
                Some(call.span()),
                None,
                vec![],
            ))
        }
    }
}
