use embed_nu::{
    nu_engine::eval_block_with_early_return,
    nu_parser,
    nu_protocol::{engine::StateWorkingSet, Signature, SyntaxShape},
    CallExt,
};

#[derive(Clone)]
pub struct EvalCommand;

impl embed_nu::nu_protocol::engine::Command for EvalCommand {
    fn name(&self) -> &str {
        "eval"
    }

    fn signature(&self) -> embed_nu::nu_protocol::Signature {
        Signature::new("eval")
            .required("script", SyntaxShape::String, "the script to eval")
            .category(embed_nu::nu_protocol::Category::Custom("Tourmalin".into()))
    }

    fn usage(&self) -> &str {
        "eval <code>"
    }

    fn run(
        &self,
        engine_state: &embed_nu::nu_protocol::engine::EngineState,
        stack: &mut embed_nu::nu_protocol::engine::Stack,
        call: &embed_nu::nu_protocol::ast::Call,
        input: embed_nu::PipelineData,
    ) -> Result<embed_nu::PipelineData, embed_nu::nu_protocol::ShellError> {
        let code: String = call.req(engine_state, stack, 0)?;
        tracing::debug!("Evaluating expression {code}");

        let mut working_set = StateWorkingSet::new(engine_state);

        let block = nu_parser::parse(&mut working_set, None, &code.into_bytes(), false);

        if !working_set.parse_errors.is_empty() {
            let err_messages = working_set
                .parse_errors
                .into_iter()
                .map(|e| format!("{e:?}"))
                .fold(String::new(), |acc, val| format!("{acc}{val}"));

            return Err(embed_nu::nu_protocol::ShellError::GenericError(
                String::from("ParseErrors"),
                err_messages,
                None,
                None,
                vec![],
            ));
        }

        let result = eval_block_with_early_return(
            engine_state,
            stack,
            &block,
            input,
            call.redirect_stdout,
            call.redirect_stdout,
        );

        result
    }
}
